@@ -59,15 +59,14 @@ class Network3Medusa():
                 self.send_webex_notification()
         
     def py2output(self):
-        print(self.command)
         self.output = subprocess.run(["python", "call_cli.py", self.command], capture_output=True)
-        print(self.output)
 
     def add_file_to_hedera(self, raw_json):
         self.client = Client.forTestnet()
         self.client.setOperator(OPERATOR_ID, OPERATOR_PRIVATE_KEY)
         tran = FileCreateTransaction()
-        fileContents = raw_json
+        fileContents = json.dumps(raw_json)
+        print(fileContents)
         resp = tran.setKeys(OPERATOR_PRIVATE_KEY.getPublicKey()).setContents(fileContents).setMaxTransactionFee(Hbar(2)).execute(self.client)
         print("nodeId: ",  resp.nodeId.toString())
         self.nodeId = resp.nodeId.toString()
@@ -77,7 +76,6 @@ class Network3Medusa():
         info = query.execute(self.client)
         print("file: ",  self.fileId.toString())
         print("File size according to `FileInfoQuery`: ", info.size)
-        
     def append_file_to_hedera(self, interface):
         tran = (FileAppendTransaction()
                 .setFileId(self.fileId)
